%set_autoconf_version 2.60
%define marker custom
%define gcc_custom_libdir %_libdir/%marker-gcc

%define gcc_branch 13

Name: gcc%gcc_branch
Version: 13.2.1
Release: alt2.p10.1

Summary: GNU Compiler Collection
# libgcc, libgomp, libstdc++ and crtstuff have
# GCC Runtime Exception.
License: LGPL-2.1-or-later and LGPL-3.0-or-later and GPL-2.0-or-later and GPL-3.0-or-later and GPL-3.0-or-later with GCC-exception-3.1

Group: Development/C
Url: https://gcc.gnu.org/

%ifarch ppc
# On ppc32, we build a 64-bit compiler with default 32-bit mode.
%define _target_platform ppc64-alt-linux
%endif

%define snapshot 20240128

%define srcver %version-%snapshot-%release
%define srcfilename gcc-%srcver
%define srcdirname gcc-%srcver
%define psuffix -%gcc_branch
%define _libexecdir /usr/libexec

%define gcc_target_libdir %_libdir/gcc/%_target_platform/%gcc_branch
%define gcc_target_libexecdir %_libexecdir/gcc/%_target_platform/%gcc_branch
%define gcc_target_platform %_target_platform

%define gcc_gdb_auto_load %_datadir/gdb/auto-load%_libdir/
%define gcc_doc_dir %_docdir/gcc%psuffix
# due to -z relro by default
%define binutils_deps binutils >= 1:2.24.0

%define gcc_sourcedir /usr/src/gcc-source

%ifarch x86_64
%define compat_platform i586-alt-linux
%define gcc_target_lib32dir /usr/lib/gcc/%compat_platform/%gcc_branch
%define gxx32idir %_includedir/c++/%gcc_branch/%compat_platform
%define gxx64idir %_includedir/c++/%gcc_branch/%_target_platform
%endif

%define libasan_arches		%ix86 x86_64 %arm aarch64 ppc64le mipsel riscv64 loongarch64
%define libhwasan_arches	x86_64 aarch64
%define libatomic_arches	%ix86 x86_64 %arm aarch64 mips mipsel s390x riscv64 ppc64le loongarch64
%define libitm_arches		%ix86 x86_64 %arm aarch64 s390x ppc64le riscv64 loongarch64
%define liblsan_arches		x86_64 aarch64 ppc64le
%define libquadmath_arches	%ix86 x86_64 ppc64le
%define libtsan_arches		x86_64 aarch64 ppc64le
%define libubsan_arches		%ix86 x86_64 %arm aarch64 ppc64le riscv64 loongarch64
%define libvtv_arches		%ix86 x86_64

# gccrs can't compile the standard libraries yet and requires annoying
# -frust-incomplete-and-experimental-compiler-do-not-use option to compile
# anything.
# See https://gcc.gnu.org/git/?p=gcc.git;a=commit;f=configure.ac;h=54a1630b4abadb8f4b207ebf4baf5c8a6b5adb9a
%def_disable rust
%ifarch %libasan_arches
%def_with libsanitizer
%endif
%ifarch %libhwasan_arches
%def_with libsanitizer
%endif
%ifarch %libtsan_arches
%def_with libsanitizer
%endif
%ifarch %libubsan_arches
%def_with libsanitizer
%endif
%ifarch %liblsan_arches
%def_with libsanitizer
%endif

%ifarch %libvtv_arches
# We desided to allow libvtv to use "__fortify_fail@GLIBC_PRIVATE".
%filter_from_requires /^libc.so.6(GLIBC_PRIVATE)/d
%endif

%set_compress_method xz
%ifarch %arm
%set_verify_elf_method textrel=relaxed
%endif

# Build parameters.
%def_enable bootstrap
# When we want to update gcc, we have to:
# 0. build gcc N in precompat mode;
# 1. build gcc N+1 with gcc N;
# 2. build gcc N in compat mode.
# Unfortunately, if we skip stage 0 at stage 2, installation of gcc N
# would be broken because it has strict requirements on libgcc1 package,
# but hasher installs libgcc1 from gcc N+1 early.
# precompat knob disables interpackage dependencies optimization
# and changes interpackage dependencies to non-strict (>=);
# this gcc is expected to be installable at stage 2.
# NB: compat and precompat are mutually exclusive.
%def_enable precompat
%def_disable compat

# For some architectures we do not want multilib support.
%ifarch riscv64 loongarch64
%def_disable multilib
%else
%def_enable multilib
%endif
%ifnarch ppc ppc64
%def_with objc
%endif
%def_disable objc_gc

%if_disabled compat
%def_enable source
%def_with jit
%endif

%if 0%{?_enable_compat:1}%{?_enable_precompat:1}
%define REQ >=
%else
%define REQ =
%endif

%def_without pdf
%def_disable doxygen
%def_disable check

%define buildtarget obj-%gcc_target_platform

Source: %srcfilename.tar

%define gcc_description \
This package contains the GNU Compiler Collection version %version.\
You'll need this package in order to compile C code.\
It is also required for all other GCC compilers.\
\
If you have multiple versions of the GNU Compiler Collection\
installed on your system, you may want to execute\
gcc%psuffix\
in order to explicitly use the GNU C compiler version %version.

%description
%gcc_description

####################################################################
# GCC Compiler

%package -n %marker-%name
Summary: GNU Compiler Collection
Group: Development/C

Conflicts: glibc-devel < 2.2.6
Requires(pre): gcc-common >= 1.4.7
Requires: %marker-cpp%gcc_branch = %EVR
Requires: %binutils_deps, glibc-devel
Requires: %marker-libgcc1 %REQ %EVR
%ifarch %libatomic_arches
Requires: %marker-libatomic1 %REQ %EVR
%endif
%ifarch %libasan_arches
Requires: %marker-libasan8 %REQ %EVR
%endif
%ifarch %libitm_arches
Requires: %marker-libitm1 %REQ %EVR
%endif
%ifarch %libtsan_arches
Requires: %marker-libtsan2 %REQ %EVR
%endif
BuildPreReq: rpm-build >= 4.0.4-alt39, %binutils_deps
BuildPreReq: gcc-c++ coreutils flex makeinfo
BuildPreReq: libelf-devel libmpc-devel libmpfr-devel
# due to manpages
BuildPreReq: perl-Pod-Parser
BuildPreReq: zlib-devel libzstd-devel

%{?_with_objc:%{?_enable_objc_gc:BuildPreReq: libgc-devel}}
%{?_enable_doxygen:BuildPreReq: doxygen graphviz tetex-latex}
%{?_with_pdf:BuildPreReq: tetex-dvips}
%{?!_without_check:%{?!_disable_check:BuildRequires: autogen, dejagnu, glibc-devel-static, /proc, /dev/pts}}

%description -n %marker-%name
%gcc_description

####################################################################
# GCC plugin

%package -n %marker-%name-plugin-devel
Summary: GCC Plugin header files
Group: Development/Other
Requires: %marker-%name = %EVR
Requires: libgmp-devel

%description -n %marker-%name-plugin-devel
This package contains header files required to build GCC plugins.

####################################################################
# GCC library

%package -n %marker-libgcc1
Summary: GCC shared support library
Group: System/Libraries
Requires(pre): glibc-core

%description -n %marker-libgcc1
This package contains GCC shared support library which is needed
e.g. for exception handling support.

####################################################################
# Atomic library

%package -n %marker-libatomic1
Summary: The GNU Atomic library
Group: System/Libraries
Requires: %marker-libgcc1 %REQ %EVR

%description -n %marker-libatomic1
This package contains the GNU Atomic library which is a GCC support
runtime library for atomic operations not supported by hardware.

%package -n %marker-libatomic%gcc_branch-devel-static
Summary: The GNU Atomic static library
Group: Development/C
Requires: %marker-libatomic1 %REQ %EVR

%description -n %marker-libatomic%gcc_branch-devel-static
This package contains GNU Atomic static library.

####################################################################
# Address Sanitizer library

%package -n %marker-libasan8
Summary: The Address Sanitizer runtime library
Group: System/Libraries
Requires: %marker-libgcc1 %REQ %EVR

%description -n %marker-libasan8
This package contains the Address Sanitizer runtime library
which is used for -fsanitize=address instrumented programs.

%package -n %marker-libasan%gcc_branch-devel-static
Summary: The Address Sanitizer static library
Group: Development/C
Requires: %marker-libasan8 %REQ %EVR

%description -n %marker-libasan%gcc_branch-devel-static
This package contains Address Sanitizer static library.

####################################################################
# Hardware-assisted Address Sanitizer library

%package -n %marker-libhwasan0
Summary: The Hardware-assisted Address Sanitizer runtime library
Group: System/Libraries
Requires: %marker-libgcc1 %REQ %EVR

%description -n %marker-libhwasan0
This package contains the Hardware-assisted Address Sanitizer runtime
library which is used for -fsanitize=hwaddress instrumented programs.

%package -n %marker-libhwasan%gcc_branch-devel-static
Summary: The Hardware-assisted Address Sanitizer static library
Group: Development/C
Requires: %marker-libhwasan0 %REQ %EVR

%description -n %marker-libhwasan%gcc_branch-devel-static
This package contains Hardware-assisted Address Sanitizer static library.

####################################################################
# Thread Sanitizer library

%package -n %marker-libtsan2
Summary: The Thread Sanitizer runtime library
Group: System/Libraries
Requires: %marker-libgcc1 %REQ %EVR

%description -n %marker-libtsan2
This package contains the Thread Sanitizer runtime library
which is used for -fsanitize=thread instrumented programs.

%package -n %marker-libtsan%gcc_branch-devel-static
Summary: The Thread Sanitizer static library
Group: Development/C
Requires: %marker-libtsan2 %REQ %EVR

%description -n %marker-libtsan%gcc_branch-devel-static
This package contains Thread Sanitizer static library.

####################################################################
# ITM library

%package -n %marker-libitm1
Summary: The GNU Transactional Memory library
Group: System/Libraries
Requires: %marker-libgcc1 %REQ %EVR

%description -n %marker-libitm1
This package contains the GNU Transactional Memory library
which is a GCC transactional memory support runtime library.

%package -n %marker-libitm%gcc_branch-devel-static
Summary: The GNU Transactional Memory static library
Group: Development/C
Requires: %marker-libitm1 %REQ %EVR

%description -n %marker-libitm%gcc_branch-devel-static
This package contains GNU Transactional Memory static libraries.

####################################################################
# OpenMP library

%package -n %marker-libgomp1
Summary: GCC OpenMP shared support library
Group: System/Libraries

%description -n %marker-libgomp1
This package contains GCC OpenMP shared support library.

%package -n %marker-libgomp%gcc_branch-devel
Summary: GCC OpenMP support files
Group: Development/Other
Requires: %marker-libgomp1 %REQ %EVR
Requires: glibc-devel

%description -n %marker-libgomp%gcc_branch-devel
This package contains GCC OpenMP headers and library.

%package -n %marker-libgomp%gcc_branch-devel-static
Summary: GCC OpenMP static support library
Group: Development/Other
Requires: %marker-libgomp%gcc_branch-devel = %EVR

%description -n %marker-libgomp%gcc_branch-devel-static
This package contains GCC OpenMP static library.

####################################################################
# GCC plugin for GDB
%package -n %marker-%name-gdb-plugin
Summary: GCC plugin for GDB
Group: Development/Debuggers
Requires: %marker-gcc%gcc_branch = %EVR
Provides: %marker-%name-gdb-plugin-devel = %EVR
Obsoletes: %marker-%name-gdb-plugin-devel < %EVR

%description -n %marker-%name-gdb-plugin
This package contains GCC plugin for GDB C expression evaluation.

####################################################################
# GCC JIT Library
%package -n %marker-libgccjit0
Summary: Library for embedding GCC inside programs and libraries
Group: System/Libraries

%description -n %marker-libgccjit0
This package contains shared library with GCC JIT front-end.

%package -n %marker-libgccjit%gcc_branch-devel
Summary: Support for embedding GCC inside programs and libraries
Group: Development/C
Requires: %marker-libgccjit0 = %EVR

%description -n %marker-libgccjit%gcc_branch-devel
This package contains header files for GCC JIT front-end.

####################################################################
# quadmath library
%package -n %marker-libquadmath0
Summary: GCC __float128 shared support library
Group: System/Libraries

%description -n %marker-libquadmath0
This package contains GCC shared support library which is needed
for __float128 math support and for Fortran REAL*16 support.

%package -n %marker-libquadmath%gcc_branch-devel
Summary: GCC __float128 support files
Group: Development/Other
Requires: %marker-libquadmath0 %REQ %EVR

%description -n %marker-libquadmath%gcc_branch-devel
This package contains headers for building Fortran programs using
REAL*16 and programs using __float128 math.

%package -n %marker-libquadmath%gcc_branch-devel-static
Summary: GCC __float128 static support library
Group: Development/Other
Requires: %marker-libquadmath%gcc_branch-devel = %EVR

%description -n %marker-libquadmath%gcc_branch-devel-static
This package contains static libraries for building Fortran programs
using REAL*16 and programs using __float128 math.

####################################################################
# Leak Sanitizer library

%package -n %marker-liblsan0
Summary: The Leak Sanitizer runtime library
Group: System/Libraries
Requires: %marker-libgcc1 %REQ %EVR

%description -n %marker-liblsan0
This package contains the Leak Sanitizer library
which is used for -fsanitize=leak instrumented programs.

%package -n %marker-liblsan%gcc_branch-devel-static
Summary: The Leak Sanitizer static library
Group: Development/C
Requires: %marker-liblsan0 %REQ %EVR

%description -n %marker-liblsan%gcc_branch-devel-static
This package contains Leak Sanitizer static runtime library.

####################################################################
# Undefined Behavior Sanitizer library

%package -n %marker-libubsan1
Summary: The Undefined Behavior Sanitizer runtime library
Group: System/Libraries
Requires: %marker-libgcc1 %REQ %EVR

%description -n %marker-libubsan1
This package contains the Undefined Behavior Sanitizer library
which is used for -fsanitize=undefined instrumented programs.

%package -n %marker-libubsan%gcc_branch-devel-static
Summary: The Undefined Behavior Sanitizer static library
Group: Development/C
Requires: %marker-libubsan1 %REQ %EVR

%description -n %marker-libubsan%gcc_branch-devel-static
This package contains Undefined Behavior Sanitizer static runtime library.

####################################################################
# VTable Verification library

%package -n %marker-libvtv0
Summary: The VTable Verification library
Group: System/Libraries
Requires: %marker-libgcc1 %REQ %EVR

%description -n %marker-libvtv0
This package contains the GNU Transactional Memory library
which is a GCC transactional memory support runtime library.

%package -n %marker-libvtv%gcc_branch-devel-static
Summary: The GNU Transactional Memory static library
Group: Development/C
Requires: %marker-libvtv0 %REQ %EVR

%description -n %marker-libvtv%gcc_branch-devel-static
This package contains GNU Transactional Memory static libraries.

####################################################################
# Preprocessor

%package -n %marker-cpp%gcc_branch
Summary: The GNU C-Compatible Compiler Preprocessor
Group: Development/C
Obsoletes: gcc-cpp egcs-cpp cpp3.0 cpp3.1
Requires(pre): gcc-common >= 1.4.7

%description -n %marker-cpp%gcc_branch
Cpp is the GNU C-Compatible Compiler Preprocessor.
The C preprocessor is a 'macro processor' which is used automatically
by the C compiler to transform your program before actual
compilation. It is called a macro processor because it allows
you to define 'macros,' which are abbreviations for longer
constructs.

The C preprocessor provides four separate facilities that you can use as
you see fit:

* Inclusion of header files. These are files of declarations that can be
  substituted into your program.
* Macro expansion. You can define 'macros,' which are abbreviations for
  arbitrary fragments of C code, and then the C preprocessor will replace
  the macros with their definitions throughout the program.
* Conditional compilation. Using special preprocessing directives,
  you can include or exclude parts of the program according to various
  conditions.
* Line control. If you use a program to combine or rearrange source files
  into an intermediate file which is then compiled, you can use line
  control to inform the compiler about where each source line originated.

If you have multiple versions of the GNU Compiler Collection
installed on your system, you may want to execute
cpp%psuffix
in order to explicitly use the GNU C Preprocessor version %version.

####################################################################
# C++ Libraries

%package -n %marker-libstdc++6
Summary: GNU Standard C++ library
Group: System/Libraries
AutoReq: yes, nopython
Requires: %marker-libgcc1 %REQ %EVR
# due to TLS (#9732)
Requires(pre): glibc-core >= 6:2.3.6-alt7

%description -n %marker-libstdc++6
This package contains a rewritten standard compliant GCC Standard C++
Library.

%package -n %marker-libstdc++%gcc_branch-devel
Summary: Header files and libraries for C++ development
Group: Development/C++
Requires(pre): gcc-c++-common >= 1.4.7
Requires: %marker-libstdc++6 %REQ %EVR
Requires: glibc-devel

%description -n %marker-libstdc++%gcc_branch-devel
This is the GNU implementation of the standard C++ libraries.
This package includes the header files and libraries needed for C++
development.  This includes rewritten implementation of STL.

%package -n %marker-libstdc++%gcc_branch-devel-static
Summary: Static libraries for C++ development
Group: Development/C++
Requires(pre): gcc-c++-common >= 1.4.7
Requires: %marker-libstdc++%gcc_branch-devel = %EVR

%description -n %marker-libstdc++%gcc_branch-devel-static
This is the GNU implementation of the standard C++ libraries.
This package includes static library needed for C++ development.

####################################################################
# C++ Compiler

%package -n %marker-%name-c++
Summary: C++ support for gcc
Group: Development/C++
Requires(pre): gcc-c++-common >= 1.4.7
Requires: %marker-%name = %EVR
Requires: %marker-libstdc++%gcc_branch-devel = %EVR

%description -n %marker-%name-c++
This package adds C++ support to the GNU Compiler Collection.
It includes support for most of the current C++ specification,
including templates and exception handling.

If you have multiple versions of the GNU Compiler Collection
installed on your system, you may want to execute
g++%psuffix
in order to explicitly use the GNU C++ compiler version %version.

####################################################################
# D Runtime

%package -n %marker-libgdruntime4
Summary: D runtime
Group: System/Libraries

%description -n %marker-libgdruntime4
This package contains DRuntime shared library which is the
low-level runtime library backing the D programming language.

%package -n %marker-libgdruntime%gcc_branch-devel
Summary: Development files for DRuntime library
Group: Development/Other
Requires: %marker-libgdruntime4 = %EVR

%description -n %marker-libgdruntime%gcc_branch-devel
This package contains development files for DRuntime library.

%package -n %marker-libgdruntime%gcc_branch-devel-static
Summary: Static DRuntime library
Group: Development/Other
Requires: %marker-libgdruntime4 = %EVR
Requires: %marker-libgdruntime%gcc_branch-devel = %EVR

%description -n %marker-libgdruntime%gcc_branch-devel-static
This package contains static DRuntime library.

%package -n %marker-libgphobos4
Summary: D runtime
Group: System/Libraries

%description -n %marker-libgphobos4
This packages contains the standard library for the D Programming
Language which is needed to run D dynamically linked programs.

%package -n %marker-libgphobos%gcc_branch-devel
Summary: Development files for DRuntime library
Group: Development/Other
Requires: %marker-libgphobos4 = %EVR

%description -n %marker-libgphobos%gcc_branch-devel
This package contains development files for DRuntime library.

%package -n %marker-libgphobos%gcc_branch-devel-static
Summary: Static D libraries
Group: Development/Other
Requires: %marker-libgphobos%gcc_branch-devel = %EVR

%description -n %marker-libgphobos%gcc_branch-devel-static
This package contains static D standard library.

####################################################################
# Objective-C Libraries

%package -n %marker-libobjc4
Summary: Objective-C runtime library
Group: System/Libraries
Requires: %marker-libgcc1 %REQ %EVR

%description -n %marker-libobjc4
This package contains Objective-C shared library which is needed to run
Objective-C dynamically linked programs.

%package -n %marker-libobjc%gcc_branch-devel
Summary: Header files and library for Objective-C development
Group: Development/Other
Requires(pre): gcc-common >= 1.4.7
Requires: %marker-libobjc4 %REQ %EVR
Requires: glibc-devel

%description -n %marker-libobjc%gcc_branch-devel
This is the GNU implementation of the standard Objective-C libraries.
This package includes the header files and library needed for
Objective-C development.

%package -n %marker-libobjc%gcc_branch-devel-static
Summary: Static libraries for Objective-C development
Group: Development/Other
Requires(pre): gcc-common >= 1.4.7
Requires: %marker-libobjc%gcc_branch-devel = %EVR

%description -n %marker-libobjc%gcc_branch-devel-static
This is the GNU implementation of the standard Objective-C libraries.
This package includes the static library needed for Objective-C
development.

####################################################################
# Objective-C Compiler

%package -n %marker-%name-objc
Summary: Objective-C support for GCC
Group: Development/Other
Requires(pre): gcc-common >= 1.4.7
Requires: %marker-%name = %EVR
Requires: %marker-libobjc%gcc_branch-devel = %EVR

%description -n %marker-%name-objc
This package provides Objective-C support for the GCC.
Mainly used on systems running NeXTSTEP, Objective-C is an
object-oriented derivative of the C language.

%package -n %marker-%name-objc++
Summary: Objective-C++ support for GCC
Group: Development/Other
Requires(pre): gcc-common >= 1.4.7
Requires: %marker-%name-objc = %EVR, %marker-%name-c++ = %EVR

%description -n %marker-%name-objc++
This package provides Objective-C++ support for the GCC.

####################################################################
# GCC sources
%package -n %marker-%name-source
Summary: GCC sources
Group: Development/Other
BuildArch: noarch

%description -n %marker-%name-source
This package contains source code of GNU Compiler Collection version %version.

####################################################################
# GCC localization
%package -n %marker-%name-locales
Summary: The GNU Compiler Collection native language support files
Group: Development/C
BuildArch: noarch
Requires: %marker-%name = %EVR

%description -n %marker-%name-locales
This packages contains files required for native language support for
the GNU Compiler Collection.

####################################################################
# GCC documentation

%package -n %marker-%name-doc
Summary: GCC documentation
Group: Development/Other
BuildArch: noarch

%description -n %marker-%name-doc
This package contains documentation for the GNU Compiler Collection
version %version.

%prep
%setup -n %srcdirname

subst 's/HAVE_FPRINTF_UNLOCKED/NEVER_&/' {fixincludes,libcpp,gcc}/system.h 

echo '%distribution %version-%release' > gcc/DEV-PHASE

# due to autoconf >= 2.69
# TODO: no go! but absence of this workaround fails overall reconfiguration
> libgo/config/go.m4

# This test causes fork failures, because it spawns way too many threads
rm -f gcc/testsuite/go.test/test/chan/goroutines.go

# Remove -I- gcc option.
find -type f -name Makefile\* -print0 |
	xargs -r0 grep -F -Zle '-I- ' -- |
	xargs -r0 sed -i 's/-I- //g' --

# Disable unwanted multilib builds.
%ifarch x86_64 mips mipsel mips64 mips64el riscv64 ppc64le
sed -i 's/\$(CC_FOR_TARGET) --print-multi-lib/echo '"'.;'/" Makefile.*
sed -i 's/\${CC-gcc} --print-multi-lib/echo '"'.;'/" config-ml.in
sed -i 's/\[ -z "\$(MULTIDIRS)" \]/true/' config-ml.in
%endif

find -type f -name \*.orig -delete -print

# Automake >= 1.10 behaviour changed.
#find -name Makefile.am -print0 |
#	xargs -r0 grep -F -lZ '_LINK = ' -- |
#	xargs -r0 sed -i '/_LDFLAGS)/! s/^\([^ ]\+\)_LINK = \$([^ ]\+)/& \$(\1_LDFLAGS)/' --

# Misdesign in libstdc++.
cp -a libstdc++-v3/config/cpu/i{4,3}86/atomicity.h

# Remove harmful autotools redeclarations.
>config/override.m4

# Replace m4_rename with m4_rename_force to fix build with autoconf >= 2.64.
if grep -F -wqs m4_rename_force /usr/share/autoconf/m4sugar/m4sugar.m4; then
	find -type f -name configure.ac -print0 |
		xargs -r0 grep -F -wlZ 'm4_rename' |
		xargs -r0 sed -i 's/\<m4_rename\>/&_force/' --
fi

# Adjust libstdc++ docs and its doxygen config.
%define onlinedocs http://gcc.gnu.org/onlinedocs
find libstdc++-v3/doc/ -type f -print0 |
	xargs -r0 grep -FZl libstdc++-html-USERS -- |
	xargs -r0 sed -i 's|libstdc++-html-USERS|%onlinedocs/libstdc++/&|' --
find libstdc++-v3/doc/ -type f -print0 |
	xargs -r0 grep -FZl '"latest-doxygen/' -- |
	xargs -r0 sed -i 's|"latest-doxygen/|"%onlinedocs/libstdc++/latest-doxygen/|' --
sed -i "s|\\(^INCLUDE_PATH[[:space:]]\\+=\\)[[:space:]]*$|\\1 $PWD/%buildtarget/%_target_platform/libstdc++-v3/include|" \
	libstdc++-v3/doc/doxygen/user.cfg.in

%build
libtoolize --copy --install --force
install -pm644 %_datadir/libtool/aclocal/*.m4 .

%autoreconf

# Regenerate configure scripts.
for f in */aclocal.m4; do
	d="${f%%/*}"
	grep ^m4_include "$d"/aclocal.m4 |
		grep -E -v '\[(libltdl/)?acinclude\.m4\]' >acinclude.m4~ ||:
	touch "$d"/acinclude.m4
	cat "$d"/acinclude.m4 >>acinclude.m4~
	mv acinclude.m4~ "$d"/acinclude.m4
	%autoreconf "$d"
	sh -n "$d"/configure
done

# Libtoolize now removes those of its build-aux files
# that haven't been installed during its invocation.
# Invoke libtoolize once more to install missing files.
# gotools is just one of those directories that could
# be used to install all necessary build-aux files.
%autoreconf gotools

./contrib/gcc_update --touch

rm -rf %buildtarget
mkdir %buildtarget
pushd %buildtarget

%if_with ada
rm -rf ada_hacks
for n in gnat %ada_binaries; do
	if [ -f "%_bindir/$n" ]; then
		continue
	fi
	if [ ! -f "%_bindir/$n%psuffix" ]; then
		echo "%_bindir/$n not found!" >&2
		exit 1
	fi
	mkdir -p ada_hacks
	ln -s "%_bindir/$n%psuffix" ada_hacks/"$n"
done
if [ -d ada_hacks ]; then
	export PATH="$PWD/ada_hacks${PATH:+:"$PATH"}"
fi
%endif

%define _configure_script ../configure
%define _configure_target --host=%_target_platform --build=%_target_platform --target=%gcc_target_platform
# Remove lto flags, these flags break GCC build, but GCC supports
# special bootstrap-lto build config.
%global optflags_lto %nil
%remove_optflags -frecord-gcc-switches %optflags_nocpp %optflags_notraceback %optflags_warnings
export CC=%__cc \
	CFLAGS="%optflags" \
	CXXFLAGS="%optflags" \
	FFLAGS="%optflags" \
	GCJFLAGS="%optflags" \
	TCFLAGS="%optflags" \
	XCFLAGS="%optflags" \
	ac_cv_file__proc_self_exe=yes \
	gcc_cv_libc_provides_ssp=yes \
	libffi_cv_ro_eh_frame=yes \
	#

CONFIGURE_OPTS="\
	--enable-shared \
	--program-suffix=%psuffix \
	--with-slibdir=/%_lib \
	--libexecdir=%_libdir \
	--with-bugurl=http://bugzilla.altlinux.org \
	--enable-__cxa_atexit \
	--enable-threads=posix \
	--enable-checking=release \
	--with-system-zlib \
	--with-zstd \
	--without-included-gettext \
	%{subst_enable multilib} \
	--enable-default-pie \
	--enable-gnu-unique-object \
	--enable-linker-build-id \
%ifnarch mips mips64 mipsel mips64el
	--with-linker-hash-style=gnu \
%endif
%ifarch %ix86
	--with-arch=%_target_cpu --with-tune=generic \
%endif
%ifarch x86_64
	--with-arch_32=i586 --with-tune_32=generic \
	--with-multilib-list=m64,m32,mx32 \
%endif
%ifarch ppc ppc64 ppc64le
	--enable-secureplt \
	--with-long-double-128 \
%endif
%ifarch ppc ppc64
	--disable-softfloat \
%endif
%ifarch ppc64le
	--enable-targets=powerpcle-linux \
	--with-cpu-32=power8 --with-tune-32=power8 \
	--with-cpu-64=power8 --with-tune-64=power8 \
%endif
%ifarch ppc
	--with-cpu=default32 \
%endif
%ifarch armh
	--with-tune=cortex-a8 --with-arch=armv7-a \
	--with-float=hard --with-fpu=vfpv3-d16 --with-abi=aapcs-linux \
	--disable-sjlj-exceptions \
%endif
%ifarch arm
	--with-arch=armv5te --with-float=soft --with-abi=aapcs-linux \
	--disable-sjlj-exceptions \
%endif
%ifarch mips mipsel mips64 mips64el
	--enable-targets=all \
	--with-arch-32=mips32r2 --with-fp-32=xx \
	--with-arch-64=mips64r2 \
%endif
%ifarch mips64 mips64el
	--with-mips-plt \
%endif
%ifarch mips mipsel
	--with-lxc1-sxc1=no \
%endif
%ifarch mipsel mips64el \
	--with-madd4=no \
%endif
%ifarch riscv64
	--with-arch=rv64gc --with-abi=lp64d \
%endif
	"

%configure \
	$CONFIGURE_OPTS \
	--with-gcc-major-version-only \
%ifarch %libvtv_arches
	--enable-vtable-verify \
%endif
%if_enabled bootstrap
	--enable-bootstrap \
	--with-build-config=bootstrap-lto \
	--enable-link-serialization=1 \
%endif
	--enable-languages="c,c++%{?_with_objc:,objc,obj-c++},lto" \
	--enable-plugin \
	%{?_with_objc:%{?_enable_objc_gc:--enable-objc-gc}} \
	#

%make_build MAKEINFOFLAGS=--no-split \
	BOOT_CFLAGS='%optflags' \
	%{?_enable_bootstrap:profiledbootstrap}

%if_enabled doxygen
%make_build -C %_target_platform/libstdc++-v3/doc doc-html-doxygen
%make_build -C %_target_platform/libstdc++-v3/doc doc-man-doxygen
%endif #enabled_doxygen
popd #%buildtarget

%if_with jit
rm -rf %buildtarget-gccjit
mkdir %buildtarget-gccjit
pushd %buildtarget-gccjit

%configure \
	$CONFIGURE_OPTS \
	--disable-bootstrap \
	--enable-host-shared \
	--enable-languages=jit \
	--with-gcc-major-version-only \
	#

%make_build MAKEINFOFLAGS=--no-split \
	BOOT_CFLAGS='%optflags' all-gcc

popd # %%buildtarget-gccjit

cp -a %buildtarget-gccjit/gcc/libgccjit.so* %buildtarget/gcc/

pushd %buildtarget/gcc/
cp -a Makefile{,.orig}
sed -e '/^CHECK_TARGETS/s/$/ check-jit/' -i Makefile
sed -e "s,^lang\.\(.*\):.*,& jit.\1," -i Makefile
touch -r Makefile.orig Makefile
rm Makefile.orig
popd # %%buildtarget/gcc/

%endif # with_jit

# build printable documentation
%if_with pdf
(cd gcc/doc; for f in gcc cpp cppinternals; do
  texi2dvi -p -t @afourpaper -t @finalout -I ../doc/include $f.texi
done)
%endif #with_pdf

%check
[ -w /dev/ptmx -a -f /proc/self/maps ] || exit
cd %buildtarget
%make_build -k check ||:
../contrib/test_summary ||:

%install
mkdir -p %buildroot%gcc_custom_libdir

# Copy various doc files here and there
CopyDocs()
{
	local n="$1"
	shift
	mkdir -p "%buildroot%gcc_doc_dir/$n"
	local d="$1"
	shift
	local f
	for f in "$d"/*{README,NEWS,LICENSE,THREADS}*; do
		[ -f "$f" ] || continue
		install -pv -m644 "$f" "%buildroot%gcc_doc_dir/$n/"
	done
}

CopyDocs gcc gcc

CopyDocs g++ gcc/cp
CopyDocs libstdc++ libstdc++-v3
cp -av libstdc++-v3/doc/html %buildroot%gcc_doc_dir/libstdc++/
if [ -d %buildtarget/%_target_platform/libstdc++-v3/doc/doxygen/html ]; then
	cp -a %buildtarget/%_target_platform/libstdc++-v3/doc/doxygen/html \
		%buildroot%gcc_doc_dir/libstdc++/
fi
if [ -d %buildtarget/%_target_platform/libstdc++-v3/doc/doxygen/man ]; then
	cp -a %buildtarget/%_target_platform/libstdc++-v3/doc/doxygen/man/man3 \
		%buildroot%_mandir/
fi

%if_with objc
CopyDocs libobjc libobjc
%endif #with_objc

pushd %buildtarget
%make_install install DESTDIR=%buildroot
popd #%buildtarget

# Remove install-tools.
rm -r %buildroot%gcc_target_libdir/install-tools

# Rename binaries which will be packaged under alternatives control.
pushd %buildroot%_bindir
	rm -vf %gcc_target_platform-gcc-%version {%gcc_target_platform-,}c++%psuffix
	for n in \
	  cpp \
	  gcc gcov gcov-tool gcov-dump \
	  g++ \
	  lto-dump \
	  ; do
		[ -f "%gcc_target_platform-$n%psuffix" ] ||
			mv -v "$n%psuffix" "%gcc_target_platform-$n%psuffix"
	done
popd

# Function that moves shared objects of the common custom libs
# to one specific dir and rest of the files to the other dir
# (with exception for the *gdb.py* files)
moving_libs(){
       for f in *.so*; do
               case "$f" in
                       *gdb.py*)
                               ;;
                       *)
                               mv "$f" "%buildroot%gcc_custom_libdir/"
                               ;;
               esac
       done
       }
# Dealing with /usr/lib64/* libs and symlinks

# Hardlink merged lto1 and lto-dump.
cmp %buildroot%gcc_target_libdir/lto1 \
	%buildroot%_bindir/%gcc_target_platform-lto-dump%psuffix

ln -f %buildroot%gcc_target_libdir/lto1 \
	%buildroot%_bindir/%gcc_target_platform-lto-dump%psuffix

ln -f %buildroot%_bindir/%gcc_target_platform-lto-dump%psuffix \
      %buildroot%_bindir/lto-dump%psuffix

# Hardlink %_bindir/cpp%psuffix
ln -f %buildroot%_bindir/%gcc_target_platform-cpp%psuffix \
      %buildroot%_bindir/cpp%psuffix

pushd %buildroot%_libdir
	rm lib*.la
	rm libssp*
	rm libiberty.a ||:
	mv *.a %buildroot%gcc_target_libdir/
%ifnarch mips s390x
	mv *.o %buildroot%gcc_target_libdir/
%endif
	for f in *.so; do
		[ "$f" != libcc1.so ] || continue
       case "$f" in
                       *gdb.py*)
                               ;;
                       *)
                               v=`objdump -p "$f" |awk '/SONAME/ {print $2}'`
                               [ -f "$v" ]
                               ln -s "%gcc_custom_libdir/$v" "%buildroot%gcc_target_libdir/$f"
                               rm "$f"
                               ;;
               esac
	done
    moving_libs
popd
# Dealing with /lib64/* libs and symlinks
pushd %buildroot/%_lib
	for f in *.so; do
		if v="$(readlink "$f")"; then
			ln -s "%gcc_custom_libdir/$v" "%buildroot%gcc_target_libdir/$f"
			rm "$f"
		else
			mv "$f" "%buildroot%gcc_target_libdir/"
		fi
	done
	moving_libs
popd

# Relocate itm, gomp and gfortran files.
%ifarch %libitm_arches
mv %buildroot%_libdir/libitm.spec %buildroot%gcc_target_libdir/
%endif
mv %buildroot%_libdir/libgomp.spec %buildroot%gcc_target_libdir/
%if_with libsanitizer
mv %buildroot%_libdir/libsanitizer.spec %buildroot%gcc_target_libdir/
%endif

# Remove precompiled headers.
rm -rf %buildroot%_includedir/c++/*/*/*/*.gch

%ifarch x86_64
mkrel32()
{
	local d32=$1 d64=$2 rel; shift 2
	mkdir -p %buildroot$d32
	rel=$(relative $d32 $d64/32)
	ln -s $rel %buildroot$d64/32
}

mkrel32 %gcc_target_lib32dir %gcc_target_libdir
mkrel32 %gxx32idir %gxx64idir
%endif # x86_64

# buildreq ignore rules.
mkdir -p %buildroot%_sysconfdir/buildreqs/files/ignore.d
cat >%buildroot%_sysconfdir/buildreqs/files/ignore.d/%marker-%name <<EOF
^%gcc_target_libdir(/include)?$
EOF

# no valid g++ manpage exists in 4.1+ series.
rm %buildroot%_man1dir/g++%psuffix.1
ln -s gcc%psuffix.1.xz %buildroot%_man1dir/g++%psuffix.1.xz

mkdir -p %buildroot%gcc_gdb_auto_load
mv -f %buildroot%_libdir/libstdc++*gdb.py* %buildroot%gcc_gdb_auto_load
pushd libstdc++-v3/python
for i in `find . -name \*.py`; do
  touch -r $i %buildroot%_datadir/gcc%psuffix/python/$i
done
touch -r hook.in %buildroot%gcc_gdb_auto_load/libstdc++*gdb.py
popd

%find_lang gcc%psuffix
%find_lang --append --output gcc%psuffix.lang cpplib%psuffix

%if_with jit
ln -s libgccjit.so.0 %buildroot%_libdir/%marker-gcc/libgccjit.so
%endif #with_jit
# Moving info files into subdir
pushd %buildroot%_infodir
       mkdir %marker-%name
       mv cpp*.info* gcc*.info* libitm.info* libgomp*.info* \
                libgccjit.info* %marker-%name
popd

%if_enabled source
mkdir -p %buildroot%gcc_sourcedir
cp %SOURCE0 %buildroot%gcc_sourcedir/
%endif
%if_enabled precompat
%define _deps_optimization 0
%endif

# Finding out what custom libraries do provide
%add_findprov_lib_path %gcc_custom_libdir

%files -n %marker-%name
%config %_sysconfdir/buildreqs/files/ignore.d/%marker-%name
%dir %gcc_doc_dir/
%gcc_doc_dir/gcc/
%_bindir/gcc%psuffix
%_bindir/gcc-ar%psuffix
%_bindir/gcc-nm%psuffix
%_bindir/gcc-ranlib%psuffix
%_bindir/lto-dump%psuffix
%_bindir/%gcc_target_platform-gcc%psuffix
%_bindir/%gcc_target_platform-gcov%psuffix
%_bindir/%gcc_target_platform-gcov-tool%psuffix
%_bindir/%gcc_target_platform-gcov-dump%psuffix
%_bindir/%gcc_target_platform-gcc-ar%psuffix
%_bindir/%gcc_target_platform-gcc-nm%psuffix
%_bindir/%gcc_target_platform-gcc-ranlib%psuffix
%_bindir/%gcc_target_platform-lto-dump%psuffix
%_man1dir/gcc%psuffix.*
%_man1dir/gcov%psuffix.*
%_man1dir/gcov-tool%psuffix.*
%_man1dir/gcov-dump%psuffix.*
%_man1dir/lto-dump%psuffix.*
%dir %gcc_target_libdir/
%dir %gcc_target_libdir/include/
%gcc_target_libdir/include/float.h
%gcc_target_libdir/include/gcov.h
%gcc_target_libdir/include/iso646.h
%gcc_target_libdir/include/limits.h
%gcc_target_libdir/include/stdalign.h
%gcc_target_libdir/include/stdarg.h
%gcc_target_libdir/include/stdatomic.h
%gcc_target_libdir/include/stdbool.h
%gcc_target_libdir/include/stddef.h
%gcc_target_libdir/include/stdfix.h
%gcc_target_libdir/include/stdint-gcc.h
%gcc_target_libdir/include/stdint.h
%gcc_target_libdir/include/stdnoreturn.h
%gcc_target_libdir/include/syslimits.h
%gcc_target_libdir/include/unwind.h
%gcc_target_libdir/include/varargs.h

%ifarch aarch64
%gcc_target_libdir/include/arm_sve.h
%endif
%ifarch aarch64 armh
%gcc_target_libdir/include/arm_acle.h
%gcc_target_libdir/include/arm_bf16.h
%gcc_target_libdir/include/arm_fp16.h
%gcc_target_libdir/include/arm_neon.h
%endif
%ifarch armh
%gcc_target_libdir/include/arm_cde.h
%gcc_target_libdir/include/arm_cmse.h
%gcc_target_libdir/include/arm_mve.h
%gcc_target_libdir/include/arm_mve_types.h
%endif
%ifarch armh arm
%gcc_target_libdir/include/mmintrin.h
%gcc_target_libdir/include/unwind-arm-common.h
%endif
%ifarch mips mipsel
%gcc_target_libdir/include/loongson.h
%gcc_target_libdir/include/msa.h
%endif
%ifarch s390x
%gcc_target_libdir/include/*intrin*.h
%endif
%ifarch %ix86 x86_64
%gcc_target_libdir/include/*intrin*.h
%gcc_target_libdir/include/cet.h
%gcc_target_libdir/include/cpuid.h
%gcc_target_libdir/include/cross-stdarg.h
%gcc_target_libdir/include/mm3dnow.h
%gcc_target_libdir/include/mm_malloc.h
%endif
%ifarch ppc ppc64 ppc64le
%gcc_target_libdir/include/*intrin*.h
%gcc_target_libdir/include/altivec.h
%gcc_target_libdir/include/amo.h
%gcc_target_libdir/include/mm_malloc.h
%gcc_target_libdir/include/ppc-asm.h
%gcc_target_libdir/include/rs6000-vecdefines.h
%gcc_target_libdir/include/si2vmx.h
%gcc_target_libdir/include/spu2vmx.h
%gcc_target_libdir/include/vec_types.h
%endif
%ifarch ppc ppc64
%gcc_target_libdir/include/spe.h
%endif
%ifarch riscv64
%gcc_target_libdir/include/riscv_vector.h
%endif
%ifarch loongarch64
%gcc_target_libdir/include/larchintrin.h
%gcc_target_libdir/include/pthread.h
%endif
%ifarch ppc64le
%gcc_target_libdir/ecrt*.o
%gcc_target_libdir/ncrt*.o
%endif
%gcc_target_libdir/crt*.o
%gcc_target_libdir/libgcc_s.so
%gcc_target_libdir/libgcc*.a
%gcc_target_libdir/libgcov.a
%ifarch %libatomic_arches
%gcc_target_libdir/libatomic.so
%endif
%ifarch %libasan_arches
%gcc_target_libdir/libasan_preinit.o
%gcc_target_libdir/libasan.so
%endif
%ifarch %libhwasan_arches
%gcc_target_libdir/include/sanitizer/hwasan_interface.h
%gcc_target_libdir/libhwasan.so
%gcc_target_libdir/libhwasan_preinit.o
%endif
%ifarch %libitm_arches
%gcc_target_libdir/libitm.so
%gcc_target_libdir/libitm.spec
%endif
%ifarch %libtsan_arches
%gcc_target_libdir/include/sanitizer/tsan_interface.h
%gcc_target_libdir/libtsan.so
%gcc_target_libdir/libtsan_preinit.o
%endif
%ifarch %liblsan_arches
%gcc_target_libdir/liblsan.so
%gcc_target_libdir/liblsan_preinit.o
%endif
%ifarch %libubsan_arches
%gcc_target_libdir/libubsan.so
%endif
%ifarch %libvtv_arches
%gcc_target_libdir/libvtv.so
%endif
%if_with libsanitizer
%gcc_target_libdir/libsanitizer.spec
%dir %gcc_target_libdir/include/sanitizer/
%gcc_target_libdir/include/sanitizer/common_interface_defs.h
%endif
%ifarch x86_64
%dir %gcc_target_lib32dir/
%gcc_target_libdir/32
%endif
%dir %gcc_target_libdir/plugin/
%gcc_target_libdir/collect2
%gcc_target_libdir/lto-wrapper
%gcc_target_libdir/lto1
%attr(0755,root,root) %gcc_target_libdir/liblto_plugin.so*
%gcc_target_libdir/plugin/gengtype

%exclude %gcc_target_libdir/include-fixed
%exclude %gcc_target_libdir/include/ssp
%exclude %gcc_target_libdir/plugin/gtype.state
%exclude %gcc_target_libdir/plugin/libcc1plugin.la
%exclude %gcc_target_libdir/plugin/libcp1plugin.la
%exclude %gcc_target_libdir/liblto_plugin.la
%exclude %_datadir/locale/de/LC_MESSAGES/libstdc++.mo
%exclude %_datadir/locale/fr/LC_MESSAGES/libstdc++.mo
%exclude %_man7dir/fsf-funding.7*
%exclude %_man7dir/gfdl.7*
%exclude %_man7dir/gpl.7*

%if_disabled compat
%files -n %marker-libgcc1
%dir %gcc_custom_libdir/
%gcc_custom_libdir/libgcc_s.so.*

%ifarch %libatomic_arches
%files -n %marker-libatomic1
%gcc_custom_libdir/libatomic.so.*
%endif

%ifarch %libasan_arches
%files -n %marker-libasan8
%gcc_custom_libdir/libasan.so.8*
%endif

%ifarch %libhwasan_arches
%files -n %marker-libhwasan0
%gcc_custom_libdir/libhwasan.so.0*
%endif

%ifarch %libtsan_arches
%files -n %marker-libtsan2
%gcc_custom_libdir/libtsan.so.2*
%endif

%ifarch %libitm_arches
%files -n %marker-libitm1
%gcc_custom_libdir/libitm.so.1*
%endif

%files -n %marker-libgomp1
%gcc_custom_libdir/libgomp.so.1*

%ifarch %liblsan_arches
%files -n %marker-liblsan0
%gcc_custom_libdir/liblsan.so.0*
%endif

%ifarch %libubsan_arches
%files -n %marker-libubsan1
%gcc_custom_libdir/libubsan.so.1*
%endif

%ifarch %libquadmath_arches
%files -n %marker-libquadmath0
%gcc_custom_libdir/libquadmath.so.0*
%endif

%ifarch %libvtv_arches
%files -n %marker-libvtv0
%gcc_custom_libdir/libvtv.so.0*
%endif
%endif #compat

%files -n %marker-%name-plugin-devel
%dir %gcc_target_libdir/plugin/
%gcc_target_libdir/plugin/include/

%ifarch %libatomic_arches
%files -n %marker-libatomic%gcc_branch-devel-static
%dir %gcc_target_libdir/
%gcc_target_libdir/libatomic.a
%endif

%ifarch %libasan_arches
%files -n %marker-libasan%gcc_branch-devel-static
%dir %gcc_target_libdir/
%dir %gcc_target_libdir/include/
%dir %gcc_target_libdir/include/sanitizer/
%gcc_target_libdir/include/sanitizer/asan_interface.h
%gcc_target_libdir/libasan.a
%endif

%ifarch %libhwasan_arches
%files -n %marker-libhwasan%gcc_branch-devel-static
%dir %gcc_target_libdir/
%gcc_target_libdir/libhwasan.a
%endif

%ifarch %libtsan_arches
%files -n %marker-libtsan%gcc_branch-devel-static
%dir %gcc_target_libdir/
%gcc_target_libdir/libtsan.a
%endif

%files -n %marker-libgomp%gcc_branch-devel
%dir %gcc_target_libdir/
%dir %gcc_target_libdir/include/
%gcc_target_libdir/include/acc_prof.h
%gcc_target_libdir/include/omp.h
%gcc_target_libdir/include/openacc.h
%gcc_target_libdir/libgomp.so
%gcc_target_libdir/libgomp.spec

%files -n %marker-libgomp%gcc_branch-devel-static
%dir %gcc_target_libdir/
%gcc_target_libdir/libgomp.a

%ifarch %libitm_arches
%files -n %marker-libitm%gcc_branch-devel-static
%dir %gcc_target_libdir/
%gcc_target_libdir/libitm.a
%endif

%ifarch %libquadmath_arches
%files -n %marker-libquadmath%gcc_branch-devel
%dir %gcc_target_libdir/
%dir %gcc_target_libdir/include/
%gcc_target_libdir/include/quadmath.h
%gcc_target_libdir/include/quadmath_weak.h
%gcc_target_libdir/libquadmath.so

%files -n %marker-libquadmath%gcc_branch-devel-static
%dir %gcc_target_libdir/
%gcc_target_libdir/libquadmath.a
%endif

%ifarch %liblsan_arches
%files -n %marker-liblsan%gcc_branch-devel-static
%dir %gcc_target_libdir/
%dir %gcc_target_libdir/include/
%dir %gcc_target_libdir/include/sanitizer/
%gcc_target_libdir/include/sanitizer/lsan_interface.h
%gcc_target_libdir/liblsan.a
%endif

%ifarch %libubsan_arches
%files -n %marker-libubsan%gcc_branch-devel-static
%dir %gcc_target_libdir/
%gcc_target_libdir/libubsan.a
%endif

%ifarch %libvtv_arches
%files -n %marker-libvtv%gcc_branch-devel-static
%dir %gcc_target_libdir/
%gcc_target_libdir/libvtv.a
%endif

%files -n %marker-cpp%gcc_branch
%_bindir/cpp%psuffix
%_bindir/%gcc_target_platform-cpp%psuffix
%_man1dir/cpp%psuffix.*
%gcc_target_libdir/cc1

%if_disabled compat
%files -n %marker-libstdc++6
%dir %gcc_custom_libdir/
%gcc_custom_libdir/libstdc++.so.*
%dir %gcc_gdb_auto_load/
%gcc_gdb_auto_load/libstdc*gdb.py*
%dir %_datadir/gcc%psuffix/
%_datadir/gcc%psuffix/python/
%endif # compat

%files -n %marker-libstdc++%gcc_branch-devel
%dir %gcc_doc_dir/
%gcc_doc_dir/libstdc++
%_includedir/c++/*
%dir %gcc_target_libdir/
%gcc_target_libdir/libstdc++.so
%gcc_target_libdir/libsupc++.a
%ifarch x86_64
%dir %gxx32idir/
%gxx64idir/32
%endif

%files -n %marker-libstdc++%gcc_branch-devel-static
%dir %gcc_target_libdir/
%gcc_target_libdir/libstdc++.a
%gcc_target_libdir/libstdc++exp.a
%gcc_target_libdir/libstdc++fs.a

%files -n %marker-%name-c++
%dir %gcc_doc_dir/
%gcc_doc_dir/g++
%_bindir/g++%psuffix
%_bindir/%gcc_target_platform-g++%psuffix
%_man1dir/g++%psuffix.*
%gcc_target_libdir/cc1plus
%gcc_target_libdir/g++-mapper-server
%ifarch %libvtv_arches
%gcc_target_libdir/vtv_*.o
%gcc_target_libdir/include/vtv_*.h
%endif

%if_with objc
%if_disabled compat
%files -n %marker-libobjc4
%gcc_custom_libdir/libobjc*.so.4*
%endif # compat

%files -n %marker-libobjc%gcc_branch-devel
%dir %gcc_doc_dir/
%gcc_doc_dir/libobjc/
%dir %gcc_target_libdir/
%gcc_target_libdir/libobjc*.so
%dir %gcc_target_libdir/include/
%gcc_target_libdir/include/objc/

%files -n %marker-libobjc%gcc_branch-devel-static
%dir %gcc_target_libdir/
%gcc_target_libdir/libobjc*.a

%files -n %marker-%name-objc
%gcc_target_libdir/cc1obj

%files -n %marker-%name-objc++
%gcc_target_libdir/cc1objplus
%endif #with_objc

%if_with jit
%files -n %marker-libgccjit0
%gcc_custom_libdir/libgccjit.so.0*

%files -n %marker-libgccjit%gcc_branch-devel
%gcc_custom_libdir/libgccjit.so
%_includedir/libgccjit*.h
%gcc_target_libdir/libgccjit.so
%endif #with_jit

%if_disabled compat
%files -n %marker-%name-gdb-plugin
%gcc_custom_libdir/libcc1.so
%gcc_target_libdir/plugin/libcc1plugin.so
%gcc_target_libdir/plugin/libcp1plugin.so
%endif # disable_compat

%if_enabled source
%files -n %marker-%name-source
%gcc_sourcedir
%endif

%files -n %marker-%name-locales -f gcc%psuffix.lang

%files -n %marker-%name-doc
%{?_enable_doxygen:%_man3dir/*}
%_infodir/%marker-%name/cpp*.info*
%_infodir/%marker-%name/gcc*.info*
%ifarch %libitm_arches
%_infodir/%marker-%name/libitm.info*
%endif
%_infodir/%marker-%name/libgomp*.info*
%{?_with_jit:%_infodir/%marker-%name/libgccjit.info*}

%if_with pdf
%doc gcc/doc/cpp*.pdf
%doc gcc/doc/gcc*.pdf
%endif #with_pdf

%changelog
* Mon Jul 15 2024 Andrey Cherepanov <cas@altlinux.org> 13.2.1-alt2.p10.1
- Backported to p10 in "custom-gcc" style (initially introduced by alexey@)
  Please refer to https://www.altlinux.org/Custom-gcc for more information

* Mon Jan 29 2024 Gleb F-Malinovskiy <glebfm@altlinux.org> 13.2.1-alt3
- Updated to merged branches from https://gcc.gnu.org/git/gcc.git:
  + vendors/redhat/heads/gcc-13-branch
  commit f783814ad6a04ae5ef44595216596a2b75eda15b;
  + releases/gcc-13 (snapshot 20240128)
  commit r13-8258-g56cbb1e0389b3a62d53ec6a1bc0c6cb3b419e08b.
- Added support for loongarch64 architecture (thx Alexey Sheplyakov).
- Changed the method for enabling the --as-needed linker feature by default,
  to avoid its usage along with sanitizer (-fsanitize=*) instrumentation
  (thx Matthias Klose).

* Sat Aug 19 2023 Gleb F-Malinovskiy <glebfm@altlinux.org> 13.2.1-alt2
- Updated to merged branch from https://gcc.gnu.org/git/gcc.git:
  + releases/gcc-13 (snapshot 20230817)
  commit r13-7730-g76b0a5783b524e4b7963f32069f1c9882d09cf38.
- riscv64: Packaged riscv_vector.h (thx Ivan A. Melnikov).
- Added riscv64 to libitm_arches (thx Ivan A. Melnikov).
- libgcc1: added prerequisites for glibc-core to resolve circular dependency.

* Sat Jul 29 2023 Gleb F-Malinovskiy <glebfm@altlinux.org> 13.2.1-alt1
- Updated to 13.2.1.
- Updated to merged branches from https://gcc.gnu.org/git/gcc.git:
  + vendors/redhat/heads/gcc-13-branch
  commit 8a3e2d71f2a0309540e68c79dadd66a06ca3da73;
  + releases/gcc-13 (snapshot 20230729)
  commit r13-7638-g446bf8fc9ddae92248adf53e7f7734c111a1176a.

* Fri Jul 21 2023 Gleb F-Malinovskiy <glebfm@altlinux.org> 13.1.1-alt2
- Updated to merged branches from git://gcc.gnu.org/git/gcc.git:
  + vendors/redhat/heads/gcc-13-branch
  commit 0d7019741b037c7e9c4e57d6de3bce6bb2ed8026;
  + releases/gcc-13 (snapshot 20230721)
  commit r13-7598-g3e95997a8dc905f0ac3a4243fb9dbf18dc70853b.
- Added %%set_autoconf_version 2.60 to workaround FTBFS caused by an upcoming
  change of the default autoconf version to 2.71.
- Applied a proposed fix for the tree-optimization/110315 bug (thx Aldy
  Hernandez and Andrew Macleod).

* Tue Jun 13 2023 Gleb F-Malinovskiy <glebfm@altlinux.org> 13.1.1-alt1
- Updated to merged branches from git://gcc.gnu.org/git/gcc.git:
  + vendors/redhat/heads/gcc-13-branch
  commit 75b6adf0fdb4d09b64cddfdce59a030f69071fc5;
  + releases/gcc-13 (snapshot 20230613)
  commit r13-7440-gb69596f7cc52481fe25b893a5dd45f9a8d6e6aef.
- Synced with Fedora gcc 13.1.1-3 and Debian gcc-13 13.1.0-3.

* Tue Apr 25 2023 Gleb F-Malinovskiy <glebfm@altlinux.org> 12.2.1-alt2
- Updated to git://gcc.gnu.org/git/gcc.git:
  + releases/gcc-12 (snapshot 20230424)
  commit r12-9468-gff74cd168e2e3ace29db96da0822a40207a329c4.
- Enabled _FORTIFY_SOURCE=3 by default for all optimization levels.

* Wed Mar 22 2023 Gleb F-Malinovskiy <glebfm@altlinux.org> 12.2.1-alt1
- Updated to merged branches from git://gcc.gnu.org/git/gcc.git:
  + vendors/redhat/heads/gcc-12-branch
  commit b3f5a0d53b84ed27cf00cfa2b9c3e2c78935c07d;
  + releases/gcc-12 (snapshot 20230322)
  commit r12-9307-g9ead8cb47b047c85deda01abe89b2a8291bb2780.
- libsanitizer (by Ivan A. Melnikov):
  + enabled asan and ubsan on riscv;
  + enabled asan on mipsel.
- riscv64: dropped --without-multilib-list from configure args to fix build
  (by Ivan A. Melnikov).

* Mon Sep 19 2022 Sergey Bolshakov <sbolshakov@altlinux.ru> 12.1.1-alt2
- configured libgccjit with major-version-only (closes: 43840)

* Wed May 18 2022 Gleb F-Malinovskiy <glebfm@altlinux.org> 12.1.1-alt1
- Updated to merged branches from git://gcc.gnu.org/git/gcc.git:
  + vendors/redhat/heads/gcc-12-branch
  commit fa107326a13af9a7d7aa0df28fe364db0f6fb171;
  + releases/gcc-12 (snapshot 20220518)
  commit r12-8392-ga048e606e6036258b98fabf9ae31a2e8a17169d4.
- Synced with Fedora gcc 12.1.1-1 and Debian gcc-12 12.1.0-2.
- Enabled zstd compression of LTO objects.

* Thu Dec 02 2021 Gleb F-Malinovskiy <glebfm@altlinux.org> 11.2.1-alt2
- Updated to merged branches from git://gcc.gnu.org/git/gcc.git:
  + vendors/redhat/heads/gcc-11-branch
  commit 0990a48aaf68b56a3737fdb290328df1da9095cc;
  + releases/gcc-11 (snapshot 20211202)
  commit 29c5aa76b47a0ac27db05b4f5f9481c45efd653e.

* Sun Sep 12 2021 Gleb F-Malinovskiy <glebfm@altlinux.org> 11.2.1-alt1
- Updated to merged branches from git://gcc.gnu.org/git/gcc.git:
  + vendors/redhat/heads/gcc-11-branch
  commit b558c8e931f0c36cda40bd60f5cdeb92452e91b5;
  + releases/gcc-11
  commit r11-8978-ga22c0458cb5605a79d4c2c192e05afabe511e320.
- Synced with Fedora gcc 11.2.1-3 and Debian gcc-11 11.2.0-3.

* Sat Jul 31 2021 Vitaly Chikunov <vt@altlinux.org> 10.3.1-alt3
- Move contents of libexecdir to libdir (ALT#40611).

* Mon Jul 05 2021 Gleb F-Malinovskiy <glebfm@altlinux.org> 10.3.1-alt2
- Backported upstream PR:
  + libstdc++/100900: add missing typename for dependent type in
  ranges::elements_view (ALT#40369).

* Fri Jul 02 2021 Gleb F-Malinovskiy <glebfm@altlinux.org> 10.3.1-alt1
- Updated to merged branches from git://gcc.gnu.org/git/gcc.git (fixes FTBFS
  with linux kernel headers >= 5.13):
  + vendors/redhat/heads/gcc-10-branch
  commit dc5e381a715a658cfcc08ba3cbaa6bc53adc596f;
  + heads/releases/gcc-10
  commit 8ce35e4c066b68d0cbc656b000ece84f7ea7741a;

* Mon Mar 15 2021 Gleb F-Malinovskiy <glebfm@altlinux.org> 10.2.1-alt3
- Updated to merged branches from git://gcc.gnu.org/git/gcc.git (ALT#39798):
  + vendors/redhat/heads/gcc-10-branch
  commit 966e4575ccd8b618811b4871e44c31bb2d11a82a;
  + releases/gcc-10
  commit a07015ad4dc18a1167720aece205deca702a1ab1.
- %name-plugin-devel: added R: libgmp-devel.

* Thu Dec 03 2020 Gleb F-Malinovskiy <glebfm@altlinux.org> 10.2.1-alt2
- Enabled hardenings by default:
  + stack clash protection;
  + PIE executables;
  + -Wl,-z,now for PIE executables.
- Merged lto1 and lto-dump programs into one binary.

* Wed Dec 02 2020 Gleb F-Malinovskiy <glebfm@altlinux.org> 10.2.1-alt1
- Updated to git://gcc.gnu.org/git/gcc.git vendors/redhat/heads/gcc-10-branch
  commit 2cd1f70a7b47cb9bd8da4aa4663e7d75b0cfcac5.
- Synced with Fedora gcc 10.2.1-9 and Debian gcc-10 10.2.0-18.

* Mon May 18 2020 Gleb F-Malinovskiy <glebfm@altlinux.org> 9.3.1-alt1
- Updated to git://gcc.gnu.org/git/gcc.git releases/gcc-9
  commit e8dcd6c79335997a80f75db389263b63dfa45ca1.
- Rebased redhat vendor branch to releases/gcc-9 branch.

* Sun Jan 26 2020 Gleb F-Malinovskiy <glebfm@altlinux.org> 9.2.1-alt3
- Updated to git://gcc.gnu.org/git/gcc.git vendors/redhat/heads/gcc-9-branch
  commit 98ca79bc91558a8ccaf487acc861a50425faf5af.
- Fixed License tag.

* Mon Nov 11 2019 Gleb F-Malinovskiy <glebfm@altlinux.org> 9.2.1-alt2
- gdc: add R: gcc-gdc-common.

* Tue Oct 08 2019 Gleb F-Malinovskiy <glebfm@altlinux.org> 9.2.1-alt1
- Updated to redhat/gcc-9-branch r274959.
- Synced with Fedora gcc 9.2.1-1 and Debian gcc-9 9.2.1-9.

* Mon Aug 05 2019 Gleb F-Malinovskiy <glebfm@altlinux.org> 8.3.1-alt5
- Applied upstream fix for PR 89906 (closes: #36972).
- Removed versioning of lib{cc1,cc1plugin,cp1plugin} libraries
  (closes: #36046).

* Tue May 07 2019 Dmitry V. Levin <ldv@altlinux.org> 8.3.1-alt4
- Updated to redhat/gcc-8-branch r270976 (Fedora gcc-8.3.1-4).

* Thu Apr 11 2019 Dmitry V. Levin <ldv@altlinux.org> 8.3.1-alt3
- Upgraded default -fstack-protector to -fstack-protector-strong.
- Fixed build with libtool 2.4.6.

* Mon Mar 11 2019 Dmitry V. Levin <ldv@altlinux.org> 8.3.1-alt2
- Updated to redhat/gcc-8-branch r269592 (Fedora gcc-8.3.1-3).

* Sat Feb 23 2019 Dmitry V. Levin <ldv@altlinux.org> 8.3.1-alt1
- Updated to redhat/gcc-8-branch r269162 (Fedora gcc-8.3.1-2).

* Mon Feb 11 2019 Dmitry V. Levin <ldv@altlinux.org> 8.2.1-alt5
- Updated to redhat/gcc-8-branch r268720 (Fedora gcc-8.2.1-8).

* Thu Feb 07 2019 Dmitry V. Levin <ldv@altlinux.org> 8.2.1-alt4
- Added ppc64le support (by glebfm@).
- Fixed profiledbootstrap build (by glebfm@).
- g++: enabled -Werror=return-type by default (closes: #36038).
- libcc1.so.0: cleaned up using a fixed libtool (closes: #36045).

* Mon Jan 14 2019 Dmitry V. Levin <ldv@altlinux.org> 8.2.1-alt3
- Updated to redhat/gcc-8-branch r267776 (Fedora gcc-8.2.1-7).
- Merged updates for mips* (by iv@) and riscv (by arei@).

* Thu Dec 27 2018 Dmitry V. Levin <ldv@altlinux.org> 8.2.1-alt2
- Updated to redhat/gcc-8-branch r267173 (Fedora gcc-8.2.1-6).

* Wed Nov 07 2018 Gleb F-Malinovskiy <glebfm@altlinux.org> 8.2.1-alt1
- Updated to redhat/gcc-8-branch r264110.
- Synced with Fedora gcc 8.2.1-4 and Debian gcc-8 8.2.0-7.

* Fri Jul 13 2018 Dmitry V. Levin <ldv@altlinux.org> 7.3.1-alt5
- Updated to redhat/gcc-7-branch r262599 (closes: #35089).
- Synced with Fedora gcc 7.3.1-6.
- Moved documentation for Fortran, Ada, and Go compilers from %name-doc
  to %name-fortran-doc, %name-gnat-doc, and %name-go-doc subpackages.

* Thu May 24 2018 Dmitry V. Levin <ldv@altlinux.org> 7.3.1-alt4
- Updated to redhat/gcc-7-branch r258210.
- Synced with Fedora gcc 7.3.1-5.
- Use --push-state --as-needed and --pop-state instead of --as-needed
  for libgcc (closes: #34935).
- Link libasan, liblsan, libtsan, and libubsan always with --no-as-needed.
- mips64el: set default ABI to N64.

* Tue Feb 20 2018 Dmitry V. Levin <ldv@altlinux.org> 7.3.1-alt3
- Do not add -Werror=stringop-overflow by default.
  Unlike the former alt-escalate-always-overflow.patch that used to
  escalate "will always overflow destination buffer" warnings to errors,
  -Werror=stringop-overflow introduced in 7.2.1-alt1 as its replacement
  generates too many false positives.

* Sun Feb 18 2018 Dmitry V. Levin <ldv@altlinux.org> 7.3.1-alt2
- aarch64: packaged liblsan and libtsan (by Sergey Bolshakov).
- arm, armh, aarch64: updated packaging of arch-specific header files
  (by Sergey Bolshakov).

* Sat Feb 17 2018 Dmitry V. Levin <ldv@altlinux.org> 7.3.1-alt1
- Updated to redhat/gcc-7-branch r257180.
- Synced with Fedora gcc 7.3.1-4.
- aarch64: fixed build.

* Wed Jan 17 2018 Gleb F-Malinovskiy <glebfm@altlinux.org> 7.2.1-alt1
- Updated to redhat/gcc-7-branch r256767.
- Synced with Fedora gcc 7.2.1-7 and Debian gcc-7 7.2.0-17.
- Packaged gcc sources as separate package.
- Dropped cxx knob from specfile.
- Dropped all alternatives.

* Wed Feb 01 2017 Gleb F-Malinovskiy <glebfm@altlinux.org> 6.3.1-alt2
- Updated to redhat/gcc-6-branch r244565.
- Synced with Fedora gcc 6.3.1-2.
- Fixed gnatmake's path to gcc (ALT#33003).
- Packaged buildreq substitution config for libmpx6-devel-static.
- Enabled java on aarch64.

* Wed Dec 21 2016 Gleb F-Malinovskiy <glebfm@altlinux.org> 6.3.1-alt1
- Updated to redhat/gcc-6-branch r243852.
- Synced with Fedora gcc 6.3.1-1 and Debian gcc-6 6.2.0-13.

* Thu Nov 10 2016 Gleb F-Malinovskiy <glebfm@altlinux.org> 5.3.1-alt4
- Updated to redhat/gcc-5-branch 234777.

* Thu Mar 10 2016 Gleb F-Malinovskiy <glebfm@altlinux.org> 5.3.1-alt3
- Moved liblto_plugin.so back into %%_libexecdir.
- Added executable bit to liblto_plugin.so.
- Backported upstram fix:
 + Enable frame pointer for TARGET_64BIT_MS_ABI when stack is
  misaligned (ALT#31834).

* Wed Feb 24 2016 Gleb F-Malinovskiy <glebfm@altlinux.org> 5.3.1-alt2
- Moved liblto_plugin.so into %%_libdir.

* Thu Dec 17 2015 Gleb F-Malinovskiy <glebfm@altlinux.org> 5.3.1-alt1
- Updated to redhat/gcc-5-branch 231358.
- Synced with Fedora gcc-5.3.1-2 and Debian 5.3.1-4.
- Added patch for aarch64 linker path.
- Changed compress_method to xz.

* Tue Aug 04 2015 Gleb F-Malinovskiy <glebfm@altlinux.org> 5.2.1-alt1
- Updated to redhat/gcc-5-branch 225895.
- Synced with Fedora gcc-5.2.1-1 and Debian gcc-5.2.1-15.

* Thu Jun 18 2015 Gleb F-Malinovskiy <glebfm@altlinux.org> 5.1.1-alt2
- Updated to redhat/gcc-5-branch 224186.
- Synced with Fedora gcc-5.1.1-4 and Debian gcc-5.1.1-12.

* Wed May 06 2015 Gleb F-Malinovskiy <glebfm@altlinux.org> 5.1.1-alt1
- Updated to redhat/gcc-5-branch r222331.
- Synced with Fedora gcc-5.1.1-1 and Debian gcc-5.1.1-1.

* Wed Mar 18 2015 Gleb F-Malinovskiy <glebfm@altlinux.org> 4.9.2-alt3
- Turned on -Wtrampolines by default.

* Tue Mar 17 2015 Gleb F-Malinovskiy <glebfm@altlinux.org> 4.9.2-alt2
- Updated to redhat/gcc-4_9-branch r220644.
- Synced with Fedora gcc-4.9.2-6 and Debian gcc-4.9.2-10.
- Dropped Linaro patch.

* Thu Nov 13 2014 Gleb F-Malinovskiy <glebfm@altlinux.org> 4.9.2-alt1
- Updated to redhat/gcc-4_9-branch r216995.
- Synced with Fedora gcc-4.9.2-1.

* Mon Oct 27 2014 Gleb F-Malinovskiy <glebfm@altlinux.org> 4.9.1-alt2
- Updated to redhat/gcc-4_9-branch r216625.
- Synced with Fedora gcc-4.9.1-13.
- Fixed base version.

* Mon Sep 22 2014 Gleb F-Malinovskiy <glebfm@altlinux.org> 4.9.1-alt1
- Updated to redhat/gcc-4_9-branch r215456.
- Synced with Fedora gcc-4.9.1-10 and Debian gcc-4.9.1-15.

* Tue Apr 08 2014 Dmitry V. Levin <ldv@altlinux.org> 4.8.2-alt3
- Synced with Fedora gcc-4.8.2-15.
- Packaged %_bindir/gcc-{ar,nm,ranlib}-4.8 (reported by led@).

* Mon Feb 17 2014 Dmitry V. Levin <ldv@altlinux.org> 4.8.2-alt2
- gnat: added alternatives support.

* Mon Feb 10 2014 Dmitry V. Levin <ldv@altlinux.org> 4.8.2-alt1
- Updated to redhat/gcc-4_8-branch r206854.
- Synced with Fedora gcc-4.8.2-14 and Debian gcc-4.8.2-15.

* Tue Jan 07 2014 Dmitry V. Levin <ldv@altlinux.org> 4.7.2-alt8
- Fixed build with GNU Autoconf >= 2.69.
- Changed build to use GNU Automake 1.11.

* Thu Jan 24 2013 Dmitry V. Levin <ldv@altlinux.org> 4.7.2-alt7
- libgfortran3, libitm1: added a strict requirement on libgcc1.

* Wed Jan 09 2013 Dmitry V. Levin <ldv@altlinux.org> 4.7.2-alt6
- libgcj: fixed GCJ_ENDORSED_DIRS (by Igor Vlasenko; closes: #28319).
- libgcj-jar: dropped %_datadir/java/gcj%gcc_branch-endorsed/.

* Fri Nov 16 2012 Dmitry V. Levin <ldv@altlinux.org> 4.7.2-alt5
- Synced with fedora gcc-4.7.2-8.

* Mon Oct 29 2012 Dmitry V. Levin <ldv@altlinux.org> 4.7.2-alt4
- Synced with fedora gcc-4.7.2-5.

* Mon Oct 01 2012 Sergey Bolshakov <sbolshakov@altlinux.ru> 4.7.2-alt3
- relocate libquadmath and libitm info files to doc subpackage
- add libquadmath substitute rule for buildreq

* Mon Oct 01 2012 Sergey Bolshakov <sbolshakov@altlinux.ru> 4.7.2-alt2
- force linker hash style to gnu

* Mon Sep 24 2012 Sergey Bolshakov <sbolshakov@altlinux.ru> 4.7.2-alt1
- 4.7.2

* Mon Aug 27 2012 Dmitry V. Levin <ldv@altlinux.org> 4.6.3-alt7
- Backported upstream changes to fix build with glibc-2.16.
- Disabled go backend for a while because it doesn't build
  with glibc-2.16.

* Fri Aug 24 2012 Dmitry V. Levin <ldv@altlinux.org> 4.6.3-alt6
- Define _FORTIFY_SOURCE only for optimization level 2 or higher.
- libgfortran4.6-devel: fixed non-strict dependency on libquadmath4.6-devel.

* Mon Aug 20 2012 Sergey Bolshakov <sbolshakov@altlinux.ru> 4.6.3-alt5
- Go language support packaged (closes: #27654)

* Mon Jul 30 2012 Sergey Bolshakov <sbolshakov@altlinux.ru> 4.6.3-alt4
- armh: use ld-linux-armhf.so.3 as dynamic linker
- armh: set defaults to hard-float for armv7

* Fri Jun 15 2012 Sergey Bolshakov <sbolshakov@altlinux.ru> 4.6.3-alt3
- fixed enforced FORTIFY_SOURCE with no opt-out

* Wed May 30 2012 Sergey Bolshakov <sbolshakov@altlinux.ru> 4.6.3-alt2
- package gfortran.spec, mistakenly omitted in prev release

* Tue May 15 2012 Sergey Bolshakov <sbolshakov@altlinux.ru> 4.6.3-alt1
- 4.6.3

* Wed Apr 11 2012 Dmitry V. Levin <ldv@altlinux.org> 4.5.3-alt3
- Updated to build with libtool 2.4.2.

* Tue Apr 03 2012 Dmitry V. Levin <ldv@altlinux.org> 4.5.3-alt2
- Merged with gcc-4_5-branch@186094.
- gcc4.5, libstdc++4.5-devel:
  packaged directories and symlinks for -m32 on x86_64.

* Wed Jan 11 2012 Dmitry V. Levin <ldv@altlinux.org> 4.5.3-alt1
- Merged with gcc-4_5-branch@183083.
- Renamed subpackages to ease subsequent gcc updates:
  libgcc4.5 -> libgcc1,
  libgcj_bc4.5 -> libgcj_bc1,
  libgomp4.5 -> libgomp1,
  libgfortran4.5 -> libgfortran3,
  libmudflap4.5 -> libmudflap0,
  libobjc4.5 -> libobjc2,
  libstdc++4.5 -> libstdc++6,
  libgcc4.5-plugin-devel -> gcc4.5-plugin-devel.

* Tue Feb 08 2011 Dmitry V. Levin <ldv@altlinux.org> 4.5.1-alt8
- Dropped -debug subpackages.
- Rebuilt for debuginfo.

* Wed Dec 01 2010 Kirill A. Shutemov <kas@altlinux.org> 4.5.1-alt7
- Synced with Fedora 4.5.1-6.

* Tue Nov 16 2010 Dmitry V. Levin <ldv@altlinux.org> 4.5.1-alt6
- Fixed build with new perl.

* Mon Nov 15 2010 Kirill A. Shutemov <kas@altlinux.org> 4.5.1-alt5
- Synced with Fedora 4.5.1-5.

* Mon Nov 08 2010 Kirill A. Shutemov <kas@altlinux.org> 4.5.1-alt4
- Fixed PR46364: g++ ICE with -O3.

* Mon Nov 08 2010 Kirill A. Shutemov <kas@altlinux.org> 4.5.1-alt3
- Fixed PR45969: ICE in build_binary_op, at c-typeck.c:9833

* Sun Nov 07 2010 Kirill A. Shutemov <kas@altlinux.org> 4.5.1-alt2
- Fixed build.
- Fixed PR45447: ICE with '-g -femit-struct-debug-baseonly' on ARM
  (closes: 24441).

* Fri Oct 15 2010 Kirill A. Shutemov <kas@altlinux.org> 4.5.1-alt1
- Synced with Fedora 4.5.1-4.
- Update Debian patches.
- Drop libffi4: no users in Sisyphus.
- Package GCC plugin header files into libgcc%%gcc_branch-plugin-devel.

* Wed Oct 13 2010 Dmitry V. Levin <ldv@altlinux.org> 4.4.5-alt1
- Synced with Fedora 4.4.5-1.

* Sat Aug 21 2010 Kirill A. Shutemov <kas@altlinux.org> 4.4.4-alt3
- Add Obsoletes/Provides to libffi4.

* Wed Aug 18 2010 Kirill A. Shutemov <kas@altlinux.org> 4.4.4-alt2
- Package libffi.so.4 for compatibility reason.

* Fri Aug 13 2010 Kirill A. Shutemov <kas@altlinux.org> 4.4.4-alt1
- Synced with Fedora 4.4.4-13

* Thu Aug 12 2010 Kirill A. Shutemov <kas@altlinux.org> 4.4.3-alt3
- Drop libffi* packages

* Fri Mar 19 2010 Kirill A. Shutemov <kas@altlinux.org> 4.4.3-alt2
- Synced with 4.4.3-10
  + PR tree-optimization/42890 (closes: 23083)

* Fri Jan 22 2010 Kirill A. Shutemov <kas@altlinux.org> 4.4.3-alt1
- Synced with FC 4.4.3-1.
  + re-add --param max-vartrack-size patch, but this time with default
    50mil instead of 5mil (closes: 22797).

* Wed Jan 13 2010 Dmitry V. Levin <ldv@altlinux.org> 4.4.2-alt4
- Rebuilt for rtld(GNU_UNIQUE) autodependencies.

* Sat Jan 09 2010 Dmitry V. Levin <ldv@altlinux.org> 4.4.2-alt3
- Added provides/obsoletes for libgomp4.1 to libgomp4.4.
- Added provides/obsoletes for libmudflap4.1 to libmudflap4.4.

* Fri Jan 08 2010 Dmitry V. Levin <ldv@altlinux.org> 4.4.2-alt2
- Synced with FC 4.4.2-20.
- Fixed build with fresh autoconf.

* Tue Oct 20 2009 Kirill A. Shutemov <kas@altlinux.org> 4.4.2-alt1
- Synced with FC 4.4.2-7
- Implement java bootstrap facility
- Workaround PR41468(ARM-specific).

* Mon Oct 05 2009 Dmitry V. Levin <ldv@altlinux.org> 4.4.1-alt3
- Updated ARM-specific fix for TEXTRELs in C++ shared objects (by Kirill A. Shutemov).

* Thu Oct 01 2009 Dmitry V. Levin <ldv@altlinux.org> 4.4.1-alt2
- Moved "make check" to %%check section.
- Packaged ARM-specific header files (by Kirill A. Shutemov).
- Implemented ASM_PREFERRED_EH_DATA_FORMAT macros for ARM (by Kirill A. Shutemov).

* Tue Aug 18 2009 Dmitry V. Levin <ldv@altlinux.org> 4.4.1-alt1
- Synced with FC 4.4.1-2.fc11 (4.4.1-20090729, svn revision 150210).

* Tue Jul 14 2009 Dmitry V. Levin <ldv@altlinux.org> 4.4.0-alt6
- Escalated "will always overflow destination buffer" warning to error.

* Mon Jul 13 2009 Dmitry V. Levin <ldv@altlinux.org> 4.4.0-alt5
- Synced with FC 4.4.0-12 (4.4.0-20090708, svn revision 149391).

* Tue Jul 07 2009 Dmitry V. Levin <ldv@altlinux.org> 4.4.0-alt4
- Synced with FC 4.4.0-10 (4.4.0-20090623, svn revision 148856).

* Sun May 17 2009 Dmitry V. Levin <ldv@altlinux.org> 4.4.0-alt3
- Synced with FC 4.4.0-5 (4.4.0-20090514, svn revision 147523).
- Removed obsolete %%install_info/%%uninstall_info calls.

* Wed May 06 2009 Dmitry V. Levin <ldv@altlinux.org> 4.4.0-alt2
- Synced with FC 4.4.0-4 (4.4.0-20090506, svn revision 147193).

* Mon May 04 2009 Dmitry V. Levin <ldv@altlinux.org> 4.4.0-alt1
- Updated to FC 4.4.0-3 (4.4.0-20090427, svn revision 146836).
- Updated Debian patches to 4.4.0-1.
- Updated ALT patches.
- Turned on -Wformat -Wformat-security by default.

* Sun May 03 2009 Dmitry V. Levin <ldv@altlinux.org> 4.3.2-alt10
- Fixed build with fresh autotools.
- Relaxed interpackage dependencies for better co-existance with gcc 4.4.x.

* Mon Apr 06 2009 Dmitry V. Levin <ldv@altlinux.org> 4.3.2-alt9
- Updated gcc4.3-java ecj build dependencies (2nd part of #18580 fix).

* Mon Apr 06 2009 Dmitry V. Levin <ldv@altlinux.org> 4.3.2-alt8
- Fixed ada FTBFS by removing -I- gcc option from makefiles.
- Updated gcc4.3-java ecj dependencies (1st part of #18580 fix).

* Tue Dec 02 2008 Dmitry V. Levin <ldv@altlinux.org> 4.3.2-alt7
- Updated gcc4.3-java build dependencies.

* Fri Nov 21 2008 Dmitry V. Levin <ldv@altlinux.org> 4.3.2-alt6
- libffi4.3: Provides/Obsoletes libffi4.1 (closes: #17887).
- Removed obsolete %%post_ldconfig/%%postun_ldconfig calls.
- Switched to alternatives-0.4.

* Thu Nov 06 2008 Dmitry V. Levin <ldv@altlinux.org> 4.3.2-alt5
- Updated to FC 4.3.2-7 (4.3.2-20081105, svn snapshot 141601).
- Moved %_datadir/java/*.jar to new libgcj%gcc_branch-jar noarch subpackage.
- Packaged gcc4.3-locales, gcc4.3-doc and libgcj4.3-src subpackages as noarch.

* Sat Nov 01 2008 Dmitry V. Levin <ldv@altlinux.org> 4.3.2-alt4
- Fixed libgcj4.1 coexistance issues.

* Wed Oct 22 2008 Dmitry V. Levin <ldv@altlinux.org> 4.3.2-alt3
- Fixed java build.
- Reenabled java on ix86/x86_64.

* Mon Oct 20 2008 Dmitry V. Levin <ldv@altlinux.org> 4.3.2-alt2
- Enhanced testsuite.
- Fixed libstdc++ doxygenated reference (closes: #3891).
- Optionally genereate libstdc++ doxygenated manpages (#15361).
- Merged ARM-related Debian patches (kas@).
- Merged Debian patch to support ObjC on ARM EABI and
  enabled ObjC on ARM (kas@).

* Mon Oct 13 2008 Dmitry V. Levin <ldv@altlinux.org> 4.3.2-alt1
- Updated to FC 4.3.2-6 (4.3.2-20081008, svn snapshot 140973).
- Updated Debian patches to 4.3.2-1.
- Updated ALT patches.
- Disabled java for a while.
- Dropped libstdc++%gcc_branch-devel-precompiled subpackage.
- Changed link spec to pass -Wl,-z,relro to the linker by default.

* Sun Jun 08 2008 Dmitry V. Levin <ldv@altlinux.org> 4.1.2-alt3
- Removed c++filt from alternatives (at@).
- Added libgcj-src subpackage (viy@).
- Moved NLS files to new locales subpackage (closes: #11510).
- Do not package changelog files.

* Mon Mar 03 2008 Dmitry V. Levin <ldv@altlinux.org> 4.1.2-alt2
- Fixed build with fresh makeinfo (avm@).

* Thu Feb 21 2008 Dmitry V. Levin <ldv@altlinux.org> 4.1.2-alt1
- Updated to RH gcc-4.1.2-14.el5.

* Wed Oct 31 2007 Alex V. Myltsev <avm@altlinux.ru> 4.1.1-alt12
- Enabled multilib.

* Tue Jan 23 2007 Dmitry V. Levin <ldv@altlinux.org> 4.1.1-alt11
- Updated to FC gcc-4.1.1-51.

* Sat Oct 14 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.1-alt10
- Updated to FC gcc-4.1.1-30.
- Removed libssp* subpackages (#10119).

* Sun Oct 08 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.1-alt9
- Added -D_FORTIFY_SOURCE=2 to default preprocessor options.
- Added -fstack-protector to default compiler options.
- Changed PARAM_SSP_BUFFER_SIZE from 8 to 4.

* Sun Oct 01 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.1-alt8
- Updated to FC gcc-4.1.1-28.
- Added --hash-style=gnu to default link options.

* Wed Sep 20 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.1-alt7
- Updated to FC gcc-4.1.1-24.
- Added /proc to java subpackage requirements.

* Tue Sep 12 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.1-alt6
- Updated to FC gcc-4.1.1-21.

* Fri Sep 08 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.1-alt5
- Updated to FC gcc-4.1.1-20.

* Thu Jun 29 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.1-alt4
- Updated to FC gcc-4.1.1-6.
- libstdc++4.1: Add requirement on glibc-core >= 6:2.3.6-alt7 (#9732).

* Thu Jun 22 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.1-alt3
- Updated to FC gcc-4.1.1-5.

* Tue Jun 13 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.1-alt2
- Updated to FC gcc-4.1.1-2.

* Thu May 25 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.1-alt1
- Updated to FC gcc-4.1.1-1.

* Fri May 19 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt4
- Updated to FC gcc-4.1.0-19.

* Mon May 15 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt3
- Updated to FC gcc-4.1.0-18.

* Sun May 14 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt2
- Updated to FC gcc-4.1.0-17.

* Sat May 13 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt1.1
- Corrected libgfortran%gcc_branch dependencies.

* Sat May 13 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt1
- Updated to FC gcc-4.1.0-16.

* Tue May 09 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt0.8
- Updated to FC gcc-4.1.0-15.

* Mon May 08 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt0.7
- Updated to FC gcc-4.1.0-14.

* Wed May 03 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt0.6
- Updated to FC gcc-4.1.0-13.

* Mon May 01 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt0.5
- Updated to FC gcc-4.1.0-12.

* Tue Apr 25 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt0.4
- Updated to FC gcc-4.1.0-11.

* Fri Apr 21 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt0.3
- Updated to FC gcc-4.1.0-10.

* Thu Apr 20 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt0.2
- Updated to FC gcc-4.1.0-9.

* Fri Apr 14 2006 Dmitry V. Levin <ldv@altlinux.org> 4.1.0-alt0.1
- Updated to FC gcc-4.1.0-8.
- Reviewed and updated patches.
- Reviewed and updated package dependencies.

* Thu Mar 09 2006 Dmitry V. Levin <ldv@altlinux.org> 3.4.5-alt2
- Relocated ffitarget.h (#9213).

* Wed Mar 08 2006 Dmitry V. Levin <ldv@altlinux.org> 3.4.5-alt1
- Updated to 3_4-rhl-branch 20051201 (RH gcc-3.4.5-2).

* Thu Mar 02 2006 Dmitry V. Levin <ldv@altlinux.org> 3.4.4-alt4
- Pass --as-needed option to GNU ld by default.
- Fixed build with make >= 3.81beta4.
- Fixed deplibs build issues on x86_64.
- Bootstrapped gnat for x86_64.
- Updated build dependencies.

* Thu Oct 20 2005 Dmitry V. Levin <ldv@altlinux.org> 3.4.4-alt3
- Fixed libgcj build to link with system libltdl.

* Wed Oct 12 2005 Dmitry V. Levin <ldv@altlinux.org> 3.4.4-alt2
- Updated to 3_4-rhl-branch 20050721 (RH gcc-3.4.4-2).
- Moved libgcj AWT peer library to separate subpackage.

* Thu Jun 23 2005 Dmitry V. Levin <ldv@altlinux.org> 3.4.4-alt1
- Updated to 3_4-rhl-branch 20050608.
- Reenabled java by default on all arches.
- Enabled build with make-3.81beta3.

* Fri Mar 18 2005 Dmitry V. Levin <ldv@altlinux.org> 3.4.3-alt6
- Merged with gcc-3_4-branch 20050314.
- Enabled testsuite by default.
- Packaged precompiled header files in separate subpackage.

* Mon Feb 28 2005 Dmitry V. Levin <ldv@altlinux.org> 3.4.3-alt5
- Updated to gcc-3_4-branch 20050222 (RH gcc-3.4.3-20).
- Removed bogus install dependence on make.
- Upgraded build and install dependencies on binutils.

* Sat Feb 12 2005 Dmitry V. Levin <ldv@altlinux.org> 3.4.3-alt4
- Updated to gcc-3_4-branch 20050210 (RH gcc-3.4.3-18).

* Tue Feb 08 2005 Dmitry V. Levin <ldv@altlinux.org> 3.4.3-alt3
- Updated to gcc-3_4-branch 20050125 (RH gcc-3.4.3-17).

* Thu Jan 13 2005 Dmitry V. Levin <ldv@altlinux.org> 3.4.3-alt2
- Updated to gcc-3_4-branch 20050105 (RH gcc-3.4.3-13).
- Converted alternatives config files to new format (0.2.0).

* Thu Dec 30 2004 Dmitry V. Levin <ldv@altlinux.org> 3.4.3-alt1
- Updated to gcc-3_4-branch 20041227 (RH gcc-3.4.3-11).

* Tue Dec 28 2004 Dmitry V. Levin <ldv@altlinux.org> 3.4.3-alt0.1
- Updated to gcc-3_4-branch 20041213 (RH gcc-3.4.3-10).
- Reviewed and updated patches.
- Reviewed and updated package dependencies.

* Sat May 15 2004 Dmitry V. Levin <ldv@altlinux.org> 3.3.3-alt5
- Rebuilt with binutils-2.15.90.0.3 and glibc-2.3.x.

* Tue Apr 20 2004 Dmitry V. Levin <ldv@altlinux.org> 3.3.3-alt4
- Synced with RH gcc-3.3.3-7 (gcc-3_3-branch 20040413).

* Fri Apr 09 2004 Dmitry V. Levin <ldv@altlinux.org> 3.3.3-alt3
- Synced with RH gcc-3.3.3-6 (gcc-3_3-branch 20040327).

* Wed Mar 17 2004 Dmitry V. Levin <ldv@altlinux.org> 3.3.3-alt2
- Synced with RH gcc-3.3.3-3 (gcc-3_3-branch 20040312).

* Fri Feb 20 2004 Dmitry V. Levin <ldv@altlinux.org> 3.3.3-alt1
- Synced with RH gcc-3.3.3-2 (gcc-3_3-branch 20040217).

* Thu Jan 22 2004 Dmitry V. Levin <ldv@altlinux.org> 3.3.3-alt0.2
- Synced with RH gcc-3.3.2-7 (gcc-3_3-branch 20040120).

* Sat Jan 03 2004 Dmitry V. Levin <ldv@altlinux.org> 3.3.3-alt0.1
- Synced with RH gcc-3.3.2-5 (gcc-3_3-branch 20031219).
- Minor specfile tweaks to ease gcc3.2/gcc3.3 upgrade.

* Wed Dec 24 2003 Dmitry V. Levin <ldv@altlinux.org> 3.3.2-alt1
- Updated to RH gcc-3.3.2-3 (gcc-3_3-branch 20031203),
  with -pie support.
- Updated patches.
- Relocated libgcc_s.so to %%gcc_target_libdir.
- Changed %%gcc_target_libdir/*.so symlink values.
- Packaged GNU Treelang compiler.
- Packaged GNAT (without alternatives support yet).

* Thu Oct 16 2003 Dmitry V. Levin <ldv@altlinux.org> 3.2.3-alt2
- Finalized alternatives transition.

* Wed Oct 15 2003 Stanislav Ievlev <inger@altlinux.ru> 3.2.3-alt1.4
- g++ manpage doesn't exist in 3.2 series, made symlink to gcc's manpage.

* Wed Oct 15 2003 Stanislav Ievlev <inger@altlinux.ru> 3.2.3-alt1.3
- added alternatives to g++ man-page, require more recent gcc-common version

* Tue Oct 14 2003 Stanislav Ievlev <inger@altlinux.ru> 3.2.3-alt1.2
- fix java alternatives config

* Tue Oct 14 2003 Stanislav Ievlev <inger@altlinux.ru> 3.2.3-alt1.1
- new alternatives support

* Mon Jun 09 2003 Dmitry V. Levin <ldv@altlinux.org> 3.2.3-alt1
- Updated to gcc_3_2-branch (20030506), dropped all non-alt patches.
- Merged:
  + RH: gcc-3_2-rhl8-branch (patches for fastjar,libffi,libiberty,libobjc);
  + Debian: gcc-3.2_3.2.3ds9-4 (15 patches);
  + SuSE (5 patches);
  + MDK (6 patches).
- Packaged libffi.
- Note that there are no rhl8-specific gcc patches in this release.

* Fri Nov 29 2002 Dmitry V. Levin <ldv@altlinux.org> 3.2.1-alt2
- Fixed typo in "%%triggerpostun c++".

* Tue Nov 26 2002 Dmitry V. Levin <ldv@altlinux.org> 3.2.1-alt1
- Updated to 3.2.1 release (3.2.1 20021119).
- Following patches merged upstream:
  + trunc_int_for_mode;
  + x86_64-q_regs_operand;
  + fold-const2;
  + i386-pr7242;
  + i386-pr7242;
  + loop-prefetch;
  + libstdc++-glibc23-1;
  + libstdc++-glibc23-2;
  + libstdc++-glibc23-3;
  + libstdc++-glibc23-4;
  + interface_only.
- Updated patches: tls, doc-gcov.
- Dropped patches: c++-tail-pad-backout.
- Added missing provides to gcc subpackage.
- Removed soname provides from -debug subpackages.
- Removed %_libdir/libstdc++.{so,a} (no longer needed).
- Moved java wrappers to separate subpackage (jdkgcj).
- Moved gccbug to separate subpackage (gcc-common).
- Removed prefixes from: jar grepjar rmic rmiregistry.
- Migrated to new alternatives scheme.

* Mon Sep 30 2002 Dmitry V. Levin <ldv@altlinux.org> 3.2.1-alt0.4
- Merged with rh gcc-3.2-7:
  * Tue Sep  3 2002 Bill Nottingham <notting@redhat.com> 3.2-7
  - fix calling of C++ destructors in certain cases
  * Tue Sep  3 2002 Jakub Jelinek <jakub@redhat.com> 3.2-6
  - update from CVS (but revert C++ tail padding patches
    for now)
  - further fixes to make libstdc++-v3 build on glibc 2.3
  - run libstdc++-v3 make check-abi on IA-32 during testing
  * Fri Aug 30 2002 Jakub Jelinek <jakub@redhat.com> 3.2-5
  - disable tail copy patches, they seem to still have problems
  - make libstdc++-v3 build on glibc 2.3 (and use thread-local
    locale model)
- libstdc++%gcc_branch:
  Added explicit versioned dependence on libgcc%gcc_branch (#0001332).
- %name-java: fixed update-alternatives.

* Fri Sep 06 2002 Dmitry V. Levin <ldv@altlinux.org> 3.2.1-alt0.3
- Disabled c++-tail-pad patch (causes internal errors in cpp code).
- Switched back to default stripping policy:
  make use of new (rpm-build >= 4.0.4-alt3) strip feature.
- Moved unstripped shared libraries to -debug subpackages.

* Fri Aug 30 2002 Dmitry V. Levin <ldv@altlinux.org> 3.2.1-alt0.2
- Merged with rh gcc-3.2-4:
  * Wed Aug 26 2002 Jakub Jelinek <jakub@redhat.com> 3.2-4
  - reorder alpha_encode_section_info checks slightly to fix an ICE
    when building glibc and to take better advantage of visibility
    attribute on Alpha
  - as gdb is not there yet, disable -momit-leaf-frame-pointer
    by default for now on IA-32
  - fix IA-64 bootstrap with tail padding patch (Jason Merrill, Daniel Berlin)
  - fix x86-64 %%RIP to %%rip, only output (%%rip) if no other relocation
    is used (Richard Henderson)
  * Fri Aug 23 2002 Jakub Jelinek <jakub@redhat.com> 3.2-3
  - take advantage of __attribute__((visibility())) on Alpha
  - avoid copying tail padding (Jason Merrill)
- Use /bin/readlink.
- Added "Conflicts: glibc-devel < 2.2.6".
- Raised alternatives priority from 15 to 30.

* Mon Aug 26 2002 Dmitry V. Levin <ldv@altlinux.org> 3.2.1-alt0.1
- Updated to snapshot 20020822.
- Merged ALT patches from 2.96 branch.
- Merged with rh gcc-3.2-2:
  * Thu Aug 22 2002 Jakub Jelinek <jakub@redhat.com> 3.2-2
  - fixed Dwarf2 DW_OP_GNU_push_tls_address patch from Richard Henderson.
  - don't mention removed -a and -ax options in the documentation
    (Nathan Sidwell, #72233).
  - fixed __typeof() followed by __asm() redirection from Alexandre Oliva.

* Wed Aug 21 2002 Dmitry V. Levin <ldv@altlinux.org> 3.2-alt3
- Rewritten interpackage dependencies to make peace with other
  versions of GCC which may be installed in the system.
- Dropped gnat.
- Added %%with/%%without logic for conditional build.
- Cleaned up descriptions.
- Cleaned up %%prep and %%build sections.
- Rewritten %%install section (no idea how it could work before).
- Set proper version information.
- Fixed doc package (info documentation was incomplete).
- Relocated documentation to %_docdir/gcc-%version/.
- Relocated libgcj headers back to compiler-specific include directory.
- Renamed libf2c* to libg2c*.
- Libificated libg2c and libobjc packages.
- gcc: moved gccbug under update-alternatives control.
- c++: moved c++filt under update-alternatives control.
- libobjc: added libobjc_gc.* libraries.
- java: moved under update-alternatives control.
  (AKA: java now should be usable).
- Moved some manpages under update-alternatives control.
- Added buildreq substitution rules.
- Added buildreq ignore rules.
- Raised alternatives priority from 5 to 15.

* Mon Aug 19 2002 Konstantin Volckov <goldhead@altlinux.ru> 3.2-alt2
- Synced with release tarball: 3.2 20020814 (release).
- Removed some patches - there are in tarball now.

* Tue Aug 13 2002 Konstantin Volckov <goldhead@altlinux.ru> 3.2-alt1
- 3.2
- Added some Cooker & RawHide patches
- Fixed update-alternatives

* Mon Jun 24 2002 Konstantin Volckov <goldhead@altlinux.ru> 3.1.1-alt1
- First build for Sisyphus
- Added some patches from CooKer
- Added patches from RH & Suse
